"""Template registry and metadata."""

TEMPLATE_REGISTRY = {
    'fastapi': [
        {
            'key': 'api',
            'name': 'API Only',
            'description': 'Basic FastAPI project with routers and clean architecture',
            'structure': [
                '📁 project_name/',
                '├── 📁 app/',
                '│   ├── __init__.py',
                '│   ├── main.py',
                '│   ├── 📁 api/',
                '│   │   ├── __init__.py',
                '│   │   └── 📁 v1/',
                '│   │       ├── __init__.py',
                '│   │       ├── router.py',
                '│   │       └── 📁 endpoints/',
                '│   │           ├── __init__.py',
                '│   │           └── health.py',
                '│   ├── 📁 core/',
                '│   │   ├── __init__.py',
                '│   │   └── config.py',
                '│   └── 📁 schemas/',
                '│       └── __init__.py',
                '├── requirements.txt',
                '├── .env.example',
                '└── README.md',
            ]
        },
        {
            'key': 'auth',
            'name': 'Authentication',
            'description': 'FastAPI with JWT authentication, user management',
            'structure': [
                '📁 project_name/',
                '├── 📁 app/',
                '│   ├── __init__.py',
                '│   ├── main.py',
                '│   ├── 📁 api/',
                '│   │   └── 📁 v1/',
                '│   │       └── 📁 endpoints/',
                '│   │           ├── auth.py',
                '│   │           ├── users.py',
                '│   │           └── health.py',
                '│   ├── 📁 core/',
                '│   │   ├── config.py',
                '│   │   ├── security.py',
                '│   │   └── dependencies.py',
                '│   ├── 📁 models/',
                '│   │   └── user.py',
                '│   └── 📁 schemas/',
                '│       ├── token.py',
                '│       └── user.py',
                '├── requirements.txt',
                '├── .env.example',
                '└── README.md',
            ]
        },
        {
            'key': 'sql',
            'name': 'SQL (SQLAlchemy + PostgreSQL)',
            'description': 'FastAPI with SQLAlchemy, PostgreSQL, and Alembic migrations',
            'structure': [
                '📁 project_name/',
                '├── 📁 app/',
                '│   ├── __init__.py',
                '│   ├── main.py',
                '│   ├── 📁 api/',
                '│   ├── 📁 core/',
                '│   │   ├── config.py',
                '│   │   └── database.py',
                '│   ├── 📁 models/',
                '│   │   ├── __init__.py',
                '│   │   └── base.py',
                '│   ├── 📁 schemas/',
                '│   ├── 📁 crud/',
                '│   │   └── __init__.py',
                '│   └── 📁 db/',
                '│       └── init_db.py',
                '├── 📁 alembic/',
                '│   ├── env.py',
                '│   └── versions/',
                '├── alembic.ini',
                '├── requirements.txt',
                '├── .env.example',
                '├── docker-compose.yml',
                '└── README.md',
            ]
        },
        {
            'key': 'mongo',
            'name': 'MongoDB (Motor)',
            'description': 'FastAPI with MongoDB using Motor (async driver)',
            'structure': [
                '📁 project_name/',
                '├── 📁 app/',
                '│   ├── __init__.py',
                '│   ├── main.py',
                '│   ├── 📁 api/',
                '│   ├── 📁 core/',
                '│   │   ├── config.py',
                '│   │   └── database.py',
                '│   ├── 📁 models/',
                '│   │   └── __init__.py',
                '│   ├── 📁 schemas/',
                '│   └── 📁 crud/',
                '├── requirements.txt',
                '├── .env.example',
                '├── docker-compose.yml',
                '└── README.md',
            ]
        },
        {
            'key': 'crm',
            'name': 'CRM Application',
            'description': 'Full CRM with users, customers, products, orders (SQL-based)',
            'structure': [
                '📁 project_name/',
                '├── 📁 app/',
                '│   ├── __init__.py',
                '│   ├── main.py',
                '│   ├── 📁 api/',
                '│   │   └── 📁 v1/',
                '│   │       └── 📁 endpoints/',
                '│   │           ├── auth.py',
                '│   │           ├── users.py',
                '│   │           ├── customers.py',
                '│   │           ├── products.py',
                '│   │           └── orders.py',
                '│   ├── 📁 core/',
                '│   │   ├── config.py',
                '│   │   ├── database.py',
                '│   │   └── security.py',
                '│   ├── 📁 models/',
                '│   │   ├── user.py',
                '│   │   ├── customer.py',
                '│   │   ├── product.py',
                '│   │   └── order.py',
                '│   ├── 📁 schemas/',
                '│   └── 📁 crud/',
                '├── 📁 alembic/',
                '├── alembic.ini',
                '├── requirements.txt',
                '├── .env.example',
                '├── docker-compose.yml',
                '└── README.md',
            ]
        },
    ],
    'flask': [
        # Flask templates can be added later
    ]
}
